@@ -22,7 +22,7 @@ class GitCommitHandler(IPythonHandler):
         g = Github(os.getenv("GIT_TOKEN"))
         branch = os.getenv("GIT_BRANCH_NAME")
         repo_name = os.getenv("GIT_REPO")
-        print("Sending git commit")
+        print("\nSending git commit\n")
         if branch:
             repo_branch = repo_name + "/" + branch
             repo = g.get_repo(repo_branch)
@@ -59,5 +59,6 @@ class GitCommitHandler(IPythonHandler):
 
 
 def setup_handlers(nbapp):
+    print("\n registering python handler \n")
     route_pattern = ujoin(nbapp.settings['base_url'], '/git/commit')
     nbapp.add_handlers('.*', [(route_pattern, GitCommitHandler)])
